==> ulyxex.1.5.2.2.with-tinyMce.zip: pages/core/admin_ftp_files.php <==
<?php
/* Ulyxex version 1.5.2.2 *****************/
class ViewFiles extends Admin {
	function __construct($dir=null){
		$this->dir = $dir;
		$this->h = New Html();
		$this->t = New Translate();

		if ($_SESSION['level'] < 2) {
			$this->Select = SELECT.FILES.".ID,".FILES.".FILENAME,".USERS.".USERNAME".FROM.FILES.INNERJOIN.USERS._ON_.FILES.".USERID = ".USERS.".ID";
		} else {
			$_[] = "USERID='".$_SESSION['userid']."'";
			$query = $this->q(SELECT."ID,USERNAME".FROM.USERS.WHERE." USEROWNER='".$_SESSION['userid']."'");
			while ( $line = $this->fetch($query) ){
				$_[] = "USERID='".$line['ID']."'";
			}
			$this->Select = SELECT.FILES.".ID,".FILES.".FILENAME,".USERS.".USERNAME".FROM.FILES.INNERJOIN.USERS._ON_.FILES.".USERID = ".USERS.".ID".$this->whereOr($_);
		}
	}
	public function update_ftp_files(){
		$h = $this->h;
		$t = $this->t;
		$data = "";
		$values = $_POST;
		foreach($values as $k=>$v){
			if ( preg_match("/add_/",$k) ){
				$now = time();
				$date = date("Y-m-d H:i:s",$now);
				$query = INSERTINTO.FILES." (FILENAME,USERID,DATEFILE) VALUES (".
										"'".$_POST['file_'.substr($k,4)]."',".
										$h->num($_POST['userid']).",'".
										$date."');";				
				$query = $this->q($query);
			}
		}
		return $this->h->h3($t->w("some values have been modified !"),"class='warning'");
	}
	public function notInDataBase(){
		$h = $this->h;
		$t = $this->t;
		$files = array();
		$filesNotInBase = array();
		$_ = array();
		$query = SELECT."FILENAME".FROM.FILES;
		$query = $this->q($query);
		while ( $line = $this->fetch($query) ) {
			$files[] = $line["FILENAME"];
		}
		$handle = opendir($this->dir);
		while ($file = readdir($handle)){
			if( // don't show this files
				preg_match("/^\./",$file) || // don't show .htaccess etc.
				$file == "index.php" // this script
				){
				continue;
			} else {
				if (!in_array($this->dir.$file,$files)) {
					$id = rand(10000,99999);
					$_[] = $h->p(
						$h->input("hidden","file_".$id,$this->dir.$file).
						$this->bordered($t->wr("add").$h->input("checkbox","add_".$id,"on")).":".
						$h->ahref($h->root_url($this->dir.$file),$h->root_url($this->dir.$file))
					);
				}
			}
		} // end while
		closedir($handle);
		$filesNotInBase = $t->wr("choose user").$this->array_users(1).$h->br();
		$filesNotInBase .= $h->input("hidden","update",1);
		$filesNotInBase .= $h->p($h->input("submit","save",$t->w("update")));
		$filesNotInBase .= implode(" ",$_);
		$filesNotInBase .= $h->p($h->input("submit","save",$t->w("update")));
		$filesNotInBase = $h->form($filesNotInBase,"ftp_files","post","admin.php?action=ftp_files");
		return $filesNotInBase;
	}
}
?>

==> ulyxex.1.5.2.6.with-tinyMce.zip: pages/core/admin_ftp_files.php <==
<?php
/* Ulyxex version 1.5.2.6 *****************/
class ViewFiles extends Admin {
	function __construct($dir=null){
		$this->dir = $dir;
		$this->h = New Html();
		$this->t = New Translate();

		if ($_SESSION['level'] < 2) {
			$this->Select = SELECT.FILES.".ID,".FILES.".FILENAME,".USERS.".USERNAME".FROM.FILES.INNERJOIN.USERS._ON_.FILES.".USERID = ".USERS.".ID";
		} else {
			$_[] = "USERID='".$_SESSION['userid']."'";
			$query = $this->q(SELECT."ID,USERNAME".FROM.USERS.WHERE." USEROWNER='".$_SESSION['userid']."'");
			while ( $line = $this->fetch($query) ){
				$_[] = "USERID='".$line['ID']."'";
			}
			$this->Select = SELECT.FILES.".ID,".FILES.".FILENAME,".USERS.".USERNAME".FROM.FILES.INNERJOIN.USERS._ON_.FILES.".USERID = ".USERS.".ID".$this->whereOr($_);
		}
	}
	public function update_ftp_files(){
		$h = $this->h;
		$t = $this->t;
		$data = "";
		$values = $_POST;
		foreach($values as $k=>$v){
			if ( preg_match("/delete_/",$k) ){
				$file = $_POST['file_'.substr($k,7)];
				@unlink($file);
			} elseif ( preg_match("/add_/",$k) ){
				$now = time();
				$date = date("Y-m-d H:i:s",$now);
				$query = INSERTINTO.FILES." (FILENAME,USERID,DATEFILE) VALUES (".
										"'".$_POST['file_'.substr($k,4)]."',".
										$h->num($_POST['userid']).",'".
										$date."');";				
				$query = $this->q($query);
			}
		}
		return $this->h->h3($t->w("some values have been modified !"),"class='warning'");
	}
	public function notInDataBase(){
		$h = $this->h;
		$t = $this->t;
		$files = array();
		$filesNotInBase = array();
		$_ = array();
		$query = SELECT."FILENAME".FROM.FILES;
		$query = $this->q($query);
		while ( $line = $this->fetch($query) ) {
			$files[] = $line["FILENAME"];
		}
		$handle = opendir($this->dir);
		while ($file = readdir($handle)){
			if( // don't show this files
				preg_match("/^\./",$file) || // don't show .htaccess etc.
				$file == "index.php" ||
				$file == "index.htm"
				){
				continue;
			} else {
				if (!in_array($this->dir.$file,$files)) {
					$id = rand(10000,99999);
					$size = $h->format_file_size(filesize($this->dir.$file));
					$params = stat($this->dir.$file);
					$date = date("Y-m-d",$params[9]);
					$_[] = $h->p(
						$h->input("hidden","file_".$id,$this->dir.$file).
						$this->bordered($t->wr("delete").$h->input("checkbox","delete_".$id,"on")).":".
						$this->bordered($t->wr("add").$h->input("checkbox","add_".$id,"on")).":".
						$h->ahref($h->root_url($this->dir.$file),$h->root_url($this->dir.$file)).":".
						$date.":".$size
					);
				}
			}
		} // end while
		closedir($handle);
		$filesNotInBase = $t->wr("choose user").$this->array_users(1).$h->br();
		$filesNotInBase .= $h->input("hidden","update",1);
		$filesNotInBase .= $h->p($h->input("submit","save",$t->w("update")));
		$filesNotInBase .= implode(" ",$_);
		$filesNotInBase .= $h->p($h->input("submit","save",$t->w("update")));
		$filesNotInBase = $h->form($filesNotInBase,"ftp_files","post","admin.php?action=ftp_files");
		return $filesNotInBase;
	}
}
?>
